@@ -46,16 +46,16 @@ LedMatrix::LedMatrix( QObject* parent, QString type, QString id )
     createMatrix();
 
     addPropGroup( { tr("Main"), {
-new IntProp <LedMatrix>("Rows"         , tr("Rows")     ,"_Leds", this, &LedMatrix::rows,     &LedMatrix::setRows,0,"uint" ),
-new IntProp <LedMatrix>("Cols"         , tr("Columns")  ,"_Leds", this, &LedMatrix::cols,     &LedMatrix::setCols,0,"uint" ),
+new IntProp <LedMatrix>("Rows"         , tr("Rows")     ,"_Leds", this, &LedMatrix::rows,     &LedMatrix::setRows, propNoCopy,"uint" ),
+new IntProp <LedMatrix>("Cols"         , tr("Columns")  ,"_Leds", this, &LedMatrix::cols,     &LedMatrix::setCols, propNoCopy,"uint" ),
 new StrProp <LedMatrix>("Color"        , tr("Color")        ,"" , this, &LedMatrix::colorStr, &LedMatrix::setColorStr,0,"enum" ),
-new BoolProp<LedMatrix>("Vertical_Pins", tr("Vertical Pins"),"" , this, &LedMatrix::verticalPins, &LedMatrix::setVerticalPins ),
-    }, groupNoCopy} );
+new BoolProp<LedMatrix>("Vertical_Pins", tr("Vertical Pins"),"" , this, &LedMatrix::verticalPins, &LedMatrix::setVerticalPins, propNoCopy ),
+    }, 0} );
     addPropGroup( { tr("Electric"), {
 new DoubProp<LedMatrix>("Threshold" , tr("Forward Voltage"),"V", this, &LedMatrix::threshold,  &LedMatrix::setThreshold ),
 new DoubProp<LedMatrix>("MaxCurrent", tr("Max Current")    ,"A", this, &LedMatrix::maxCurrent, &LedMatrix::setMaxCurrent ),
 new DoubProp<LedMatrix>("Resistance", tr("Resistance")     ,"Ω", this, &LedMatrix::res,        &LedMatrix::setRes ),
-    }, groupNoCopy} );
+    }, 0} );
 }
 LedMatrix::~LedMatrix(){}
 
